@@ -11,9 +11,14 @@ import re
 import sys
 import builtins
 from functools import partial
+import os
 from cilog.utils import CiLogStdOut
-from prettytable import PrettyTable, MARKDOWN
-from pandas import DataFrame
+try:
+    import pandas
+except:
+    os.system('pip install pandas --upgrade')
+    os.system('pip install tabulate --upgrade')
+    import pandas
 import ast
 
 
@@ -100,20 +105,18 @@ class CustomLogger(logging.Logger):
                 for i, key in enumerate(table_dict.keys()):
                     table_dict[key].append(row[i])
 
-            df = DataFrame(table_dict)
+            df = pandas.DataFrame(table_dict)
 
             if format == 'markdown':
-                table = df.to_markdown(index=False)
+                try:
+                    table = df.to_markdown(index=False)
+                except:
+                    print('#W#pandas version too low.')
+                    os.system('pip install pandas --upgrade')
+                    table = df.to_markdown(index=False)
 
             if format == 'latex':
                 table = df.to_latex(index=False)
-            # table = PrettyTable()
-            # table.field_names = list_table[0]
-            # for row_index in range(1, len(list_table)):
-            #     table.add_row(list_table[row_index])
-            #
-            # if format == 'markdown':
-            #     table.set_style(MARKDOWN)
 
             self._log(logging.ORIGIN, table, args, **kwargs)
             self._log(logging.ORIGIN, '\n', args, **kwargs)
